#!/bin/bash
# script permettant de détecter les écrans et de configurer correctement l'affichage sur les vidéoprojecteurs.
# les pc avec des cartes intel intégées n'ont pas de "vrai" ports VGA, mais 3 displayports, avec un adaptateur.
# la détection de l'écran branché en VGA se fait mal ou pas du tout, ce qui pose de nombreux problèmes 
# 
# ce script est donc destiné à assigner au boot un fichier EDID comportant les données du moniteur/vpi
#
# pour fonctionner, il faut que le fichier EDID ait été au préalable récupéré en connectant le moniteur sur un port DP/HDMI
#
# sont inclus : un fichier générique de moniteur "full hd" et les vpi Epson
# 
# pour les PC HP 240, le port VGA est DP-3
#
# fichiers edid persos à copier dans /usr/lib/firmware/edid/
# les suivants sont mis de façon générique
# ATTENTION !!! 
# si le moniteur ne supporte pas le full HD et est branché en VGA, il faut changer le fichier $mon

vpi="epson-pj-edid.bin"
mon="generic-hd-edid.bin"

monitorv=$(edid-decode /usr/lib/firmware/edid/$vpi  | grep "Display Product Name"| sed "s/^.*'\(.*\)'/\1/")
res=$(edid-decode /usr/lib/firmware/edid/$vpi | grep "native" | awk '{print $3}')
if [ -z "$res" ]; then
	res=$(edid-decode /usr/lib/firmware/edid/$vpi | grep "DTD 1:" | awk '{print $3}')
fi 
if [ -f "/sys/class/drm/card0-DP-1/edid" ]; then
	h=$(echo $res | cut -d"x" -f 1)
	monitor1=$(edid-decode /sys/class/drm/card0-DP-1/edid | grep "Display Product Name"| sed "s/^.*'\(.*\)'/\1/")
	res1=$(edid-decode /sys/class/drm/card0-DP-1/edid | grep "native" | awk '{print $3}')
	if [ -z "$res1" ]; then
		res1=$(edid-decode /sys/class/drm/card0-DP-1/edid | grep "DTD 1:" | awk '{print $3}')
	fi
	h1=$(echo $res1 | cut -d"x" -f 1)
fi
if [ -f "/sys/class/drm/card0-DP-2/edid" ]; then
	monitor2=$(edid-decode /sys/class/drm/card0-DP-2/edid | grep "Display Product Name"| sed "s/^.*'\(.*\)'/\1/")
	res2=$(edid-decode /sys/class/drm/card0-DP-2/edid | grep "native" | awk '{print $3}')
	if [ -z "$res2" ]; then
		res2=$(edid-decode /sys/class/drm/card0-DP-2/edid | grep "DTD 1:" | awk '{print $3}')
	fi
	h2=$(echo $res2 | cut -d"x" -f 1)
fi
if [ -f "/sys/class/drm/card0-DP-3/edid" ]; then
	monitor3=$(edid-decode /sys/class/drm/card0-DP-3/edid | grep "Display Product Name"| sed "s/^.*'\(.*\)'/\1/")
	res3=$(edid-decode /sys/class/drm/card0-DP-3/edid | grep "native" | awk '{print $3}')
	if [ -z "$res3" ]; then
		res3=$(edid-decode /sys/class/drm/card0-DP-3/edid | grep "DTD 1:" | awk '{print $3}')
	fi
	h3=$(echo $res2 | cut -d"x" -f 1)
fi

# on regarde si le vpi et l'écran sont sur les ports 1 ou 2, dans ce cas on ne fait rien

if [ "$monitor1" == "EPSON PJ" ]; then
	monitor=$monitor1
	res=$res1
	[ -n "$monitor2" ] && exit 0
fi
if [ "$monitor2" == "EPSON PJ" ]; then
	monitor=$monitor2
	res=$res2
	[ -n "$monitor1" ] && exit 0
fi

if [ "$res" != "$(cat /etc/sambaedu/applications/res.txt)" ]; then
	if  [ "$monitor" == "EPSON PJ" ]; then
		if [ -z "$monitor3" ]; then
			# Si in n'es pas détecté on assigne un EDID pour le moniteur en VGA
			sed -i "s/GRUB_CMDLINE_LINUX_DEFAULT=\"quiet splash.*$/GRUB_CMDLINE_LINUX_DEFAULT=\"quiet splash drm.edid_firmware=DP-3:edid\/$mon\"/" /etc/default/grub
			sed -i "s/GRUB_GFX_MODE=.*$/GRUB_GFX_MODE=$res/" /etc/default/grub
			echo $res > /etc/sambaedu/applications/res.txt
			update-grub
		fi
	else
		# le vpi est sensé être en VGA
		if [ -z "$monitor3" ]; then
			# on assigne un EDID pour le moniteur en VGA
			sed -i "s/GRUB_CMDLINE_LINUX_DEFAULT=\"quiet splash.*$/GRUB_CMDLINE_LINUX_DEFAULT=\"quiet splash drm.edid_firmware=DP-3:edid\/$vpi\"/" /etc/default/grub
			sed -i "s/GRUB_GFX_MODE=.*$/GRUB_GFX_MODE=$res/" /etc/default/grub
			echo $res > /etc/sambaedu/applications/res.txt
			update-grub
		fi
	fi
fi